@@ -1,8 +1,8 @@
 #' Adds a Parameter for Clinical Benefit
 #'
 #' @description
-#' `r lifecycle::badge("superseded")` The `derive_param_clinbenefit()` function
-#' has been superseded in favor of `derive_extreme_event()`.
+#' `r lifecycle::badge("deprecated")` The `derive_param_clinbenefit()` function
+#' has been deprecated in favor of `derive_extreme_event()`.
 #'
 #' Adds a parameter for clinical benefit/disease control
 #'
@@ -49,9 +49,6 @@
 #'   + `N` for subjects present in `dataset_adsl` but not present in `dataset`
 #'   or the dataset identified in `source_resp`.
 #'
-#'   \item `AVAL` is derived using `AVALC` as input to the function specified in
-#'   `aval_fun`.
-#'
 #'   \item The variables specified by `set_values_to` are added to the new observations
 #'   with values equal to the values specified in the same.
 #'
@@ -98,7 +95,7 @@
 #' that must elapse before an evaluable non-PD assessment counts toward determining
 #' clinical benefit.
 #'
-#' @param aval_fun *Deprecated*, please use `set_values_to` instead.
+#' @param aval_fun `r lifecycle::badge("deprecated")` Please use `set_values_to` instead.
 #'
 #' Function to map character analysis value (`AVALC`) to numeric analysis value
 #' (`AVAL`)
@@ -118,8 +115,8 @@
 #'
 #' @return The input dataset with a new parameter for clinical benefit
 #'
-#' @family superseded
-#' @keywords superseded
+#' @family deprecated
+#' @keywords deprecated
 #'
 #' @export
 #'
@@ -128,6 +125,10 @@
 #' library(lubridate)
 #' library(dplyr)
 #' library(admiral)
+#' # ensure that `date_source()` from admiralonco is used to avoid deprecation
+#' # warning
+#' unloadNamespace("admiralonco")
+#' library(admiralonco)
 #'
 #' adsl <- tibble::tribble(
 #'   ~USUBJID, ~TRTSDT,
@@ -204,6 +205,17 @@ derive_param_clinbenefit <- function(dataset,
                                      clinben_vals = c("CR", "PR", "SD", "NON-CR/NON-PD"),
                                      set_values_to,
                                      subject_keys = get_admiral_option("subject_keys")) {
+  deprecate_inform(
+    when = "1.4",
+    what = "derive_param_clinbenefit()",
+    with = "admiral::derive_extreme_event()",
+    details = c(
+      x = "This message will turn into a warning at the beginning of 2027.",
+      i = "See admiral's deprecation guidance:
+      https://pharmaverse.github.io/admiraldev/dev/articles/programming_strategy.html#deprecation"
+    )
+  )
+
   # Assertions and quotes
   reference_date <- assert_symbol(enexpr(reference_date))
   assert_vars(subject_keys)
@@ -227,13 +239,11 @@ derive_param_clinbenefit <- function(dataset,
   assert_character_vector(clinben_vals)
 
   if (!missing(aval_fun)) {
-    deprecate_warn(
+    deprecate_stop(
       "0.4.0",
       "derive_param_clinbenefit(aval_fun = )",
       "derive_param_clinbenefit(set_values_to = )"
     )
-    assert_function(aval_fun)
-    set_values_to <- exprs(!!!set_values_to, AVAL = {{ aval_fun }}(AVALC))
   }
 
   source_names <- names(source_datasets)
@@ -245,7 +255,7 @@ derive_param_clinbenefit <- function(dataset,
           "The dataset names specified for `source_pd` and `source_resp` must be \n",
           "included in the list specified for the `source_datasets` parameter.\n",
           "Following names were provided by `source_datasets`:\n",
-          enumerate(source_names, quote_fun = squote)
+          "{.val {source_names}}"
         )
       )
     }
@@ -256,7 +266,7 @@ derive_param_clinbenefit <- function(dataset,
           "The dataset names specified for `source_resp` must be \n",
           "included in the list specified for the `source_datasets` parameter.\n",
           "Following names were provided by `source_datasets`:\n",
-          enumerate(source_names, quote_fun = squote)
+          "{.val {source_names}}"
         )
       )
     }
@@ -284,12 +294,14 @@ derive_param_clinbenefit <- function(dataset,
 
   if (!is.null(source_pd)) {
     # Look for valid non-PD measurements after window from reference date
-    ovr_data <- filter_pd(
-      dataset = dataset,
-      filter = !!filter_source,
-      source_pd = source_pd,
-      source_datasets = source_datasets,
-      subject_keys = subject_keys
+    suppressMessages(
+      ovr_data <- filter_pd(
+        dataset = dataset,
+        filter = !!filter_source,
+        source_pd = source_pd,
+        source_datasets = source_datasets,
+        subject_keys = subject_keys
+      )
     )
   } else {
     #++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
