@@ -1,8 +1,8 @@
 #' Filter up to First PD (Progressive Disease) Date
 #'
 #' @description
-#' `r lifecycle::badge("superseded")` The `filter_pd()` function has been
-#' superseded in favor of `filter_relative()`.
+#' `r lifecycle::badge("deprecated")` The `filter_pd()` function has been
+#' deprecated in favor of `filter_relative()`.
 #'
 #' Filter a dataset to only include the source parameter records up to and
 #' including the first PD (progressive disease). These records are passed to
@@ -49,14 +49,17 @@
 #'
 #' @export
 #'
-#' @family superseded
-#' @keywords superseded
+#' @family deprecated
+#' @keywords deprecated
 #'
 #' @examples
 #'
 #' library(dplyr)
 #' library(lubridate)
 #' library(admiral)
+#' # ensure that `date_source()` from admiralonco is used to avoid deprecation
+#' # warning
+#' unloadNamespace("admiralonco")
 #' library(admiralonco)
 #'
 #' # Filter OVR records up to first PD, first PD date provided in separate BDS dataset (adevent)
@@ -188,6 +191,17 @@ filter_pd <- function(dataset,
                       source_pd,
                       source_datasets,
                       subject_keys = get_admiral_option("subject_keys")) {
+  deprecate_inform(
+    when = "1.4",
+    what = "filter_pd()",
+    with = "admiral::filter_relative()",
+    details = c(
+      x = "This message will turn into a warning at the beginning of 2027.",
+      i = "See admiral's deprecation guidance:
+      https://pharmaverse.github.io/admiraldev/dev/articles/programming_strategy.html#deprecation"
+    )
+  )
+
   # Check input arguments
   assert_vars(subject_keys)
   assert_data_frame(dataset,
@@ -202,12 +216,12 @@ filter_pd <- function(dataset,
   assert_list_of(source_datasets, "data.frame")
   source_names <- names(source_datasets)
   if (!source_pd$dataset_name %in% source_names) {
-    abort(
+    cli_abort(
       paste0(
         "The dataset name specified for `source_pd` must be included in the list\n",
         " specified for the `source_datasets` parameter.\n",
         "Following names were provided by `source_datasets`:\n",
-        enumerate(source_names, quote_fun = squote)
+        "{.val {source_names}}"
       )
     )
   }
@@ -226,3 +240,63 @@ filter_pd <- function(dataset,
     filter(is.na(temp_date) | ADT <= temp_date) %>%
     select(-temp_date)
 }
+
+#' Create a `date_source` object
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")` The `date_source()` function has been
+#' deprecated without replacement as all functions using the `source_pd`
+#' argument are deprecated as well.
+#'
+#' Create a `date_source` object as input for `source_pd` argument in
+#' `{admiralonco}` functions.
+#'
+#' @param dataset_name The name of the dataset, i.e. a string, used to search for
+#'   the date.
+#'
+#' @param filter An unquoted condition for filtering `dataset`.
+#'
+#' @param date A variable or an expression providing a date. A date or a
+#'   datetime can be specified. An unquoted symbol or expression is expected.
+#'
+#' @param set_values_to Variables to be set
+#'
+#' @family deprecated
+#' @keywords deprecated
+#'
+#' @export
+#'
+#' @return An object of class `date_source`.
+#'
+#' @examples
+#'
+#' pd <- date_source(
+#'   dataset_name = "adrs",
+#'   date = ADT,
+#'   filter = PARAMCD == "PD"
+#' )
+date_source <- function(dataset_name,
+                        filter = NULL,
+                        date,
+                        set_values_to = NULL) {
+  deprecate_inform(
+    when = "1.4.0",
+    what = "date_source()",
+    details = c(
+      x = "This message will turn into a warning {at the beginning of 2027}.",
+      i = paste0(
+        "See admiral's deprecation guidance: https://pharmaverse.github.io/",
+        "admiraldev/dev/articles/programming_strategy.html#deprecation"
+      )
+    )
+  )
+
+  out <- list(
+    dataset_name = assert_character_scalar(dataset_name),
+    filter = assert_filter_cond(enexpr(filter), optional = TRUE),
+    date = assert_expr(enexpr(date)),
+    set_values_to = assert_expr_list(set_values_to, named = TRUE, optional = TRUE)
+  )
+  class(out) <- c("date_source", "source", "list")
+  out
+}
